@@ -8,6 +8,8 @@
 ## 2020-08-27 radical revamp of occasion, trap and animalID functions, 
 ##            with unified code
 ## 2020-11-07 alive() rewritten to match preceding
+## 2022-01-05 fixed alive() problem with one animal
+## 2022-08-23 summary.mask and summary.popn removed to separate files
 ###############################################################################
 
 # Generic methods for extracting attributes etc
@@ -18,6 +20,7 @@ markocc    <- function (object, ...) UseMethod("markocc")
 Tu         <- function (object, ...) UseMethod("Tu")
 Tm         <- function (object, ...) UseMethod("Tm")
 Tn         <- function (object, ...) UseMethod("Tn")
+nontarget  <- function (object, ...) UseMethod("nontarget")
 clusterID  <- function (object, ...) UseMethod("clusterID")
 clustertrap <- function (object, ...) UseMethod("clustertrap")
 covariates <- function (object, ...) UseMethod("covariates")
@@ -110,6 +113,11 @@ Tn.default <- function (object, ...)       {
     else attr(object,'Tn',exact = TRUE)
 }
 
+nontarget.default <- function (object, ...) {
+    if (ms(object)) lapply(object, nontarget.default, ...)
+    else attr(object,'nontarget',exact = TRUE)
+}
+
 sighting <- function(object) {
     mocc <- unlist(markocc(object))
     if (is.null(mocc)) {
@@ -304,24 +312,24 @@ alongtransect <- function (object, tol = 0.01) {
     }
     if (!inherits(object, 'capthist'))
         stop ("requires 'capthist' object")
-
+    
     if (ms(object)) {
-        lapply(object, alongtransect)
+        lapply(object, alongtransect, tol = tol)
     }
     else {
         trps <- traps(object)
-
+        
         if (all(detector(trps) %in% c('transectX', 'transect'))) {
-
-#             trans <- trap(object, names = TRUE)
-#             xyi <- xy(object)
-#             ## 2015-09-02 change to fix occsim: remove 'S' prefix
-#             lxy <- split (trps, levels(transectID(trps)), prefix = "")
-
+            
+            #             trans <- trap(object, names = TRUE)
+            #             xyi <- xy(object)
+            #             ## 2015-09-02 change to fix occsim: remove 'S' prefix
+            #             lxy <- split (trps, levels(transectID(trps)), prefix = "")
+            
             trans <- trap(object, names = FALSE, sortorder = 'ksn')
             xyi <- xy(object)
             lxy <- split (trps, transectID(trps))
-
+            
             sapply(1:nrow(xyi), ptalongtransect)
         }
         else
@@ -329,6 +337,41 @@ alongtransect <- function (object, tol = 0.01) {
     }
 }
 
+# under development 2021-12-11, 2022-02-01
+distancetotransect <- function (object) {
+    if (!inherits(object, 'capthist'))
+        stop ("requires 'capthist' object")
+    
+    if (ms(object)) {
+        lapply(object, distancetotransect)
+    }
+    else {
+        trps <- traps(object)
+        
+        if (all(detector(trps) %in% c('transectX', 'transect'))) {
+            
+            xyi <- xy(object)
+            
+            # split by transect
+            lxy <- split (trps, transectID(trps))
+            vlist <- lapply(lxy, as.matrix)
+            
+            # each transect as sfg
+            vlist <- lapply(vlist, st_linestring)
+            # combine linestrings in one sfc
+            v <- st_sfc(vlist)
+            xy <- st_as_sf(as.data.frame(xyi), coords = 1:2)
+            neari <- st_nearest_feature(xy, v)
+            st_distance(xy,v)[,neari]   # distance to nearest feature
+
+        }
+        else
+            NULL
+    }
+}
+
+
+
 clusterID <- function (object) {
     if (ms(object)) {
         lapply(object, clusterID)
@@ -533,7 +576,9 @@ alive <- function (object, sortorder = c('snk','ksn')) {
         }
         else {
             tmp <- captmatrix(object, sortorder)
-            temp <- sign(object[tmp[,1:3]]) > 0
+            ## 2022-01-05 fixed problem with one animal
+            ## temp <- sign(object[tmp[,1:3]]) > 0
+            temp <- sign(object[tmp[,1:3, drop = FALSE]]) > 0
             out <- rep(temp, tmp[,4])
         }
         as.logical(out)
@@ -622,10 +667,14 @@ detectionindex <- function (object) {
 }
 
 polyarea <- function (xy, ha = TRUE) {
-    if (inherits(xy, 'SpatialPolygons')) {
-        if (!requireNamespace('rgeos', quietly = TRUE))
-            stop ("package rgeos is required for area of SpatialPolygons")
-        temparea <- rgeos::gArea(xy)
+    if (inherits(xy, c('sf','sfc','sfg'))) {
+        temparea <- sum(st_area(xy))
+    }
+    else if (inherits(xy, 'SpatialPolygons')) {
+        temparea <- sum(st_area(st_as_sf(xy)))
+    }
+    else if (inherits(xy, 'SpatVector')) {
+        temparea <- sum(st_area(st_as_sf(xy)))
     }
     else {
         nr <- length(xy$x)
@@ -879,7 +928,7 @@ flip.default <- function (object, lr = FALSE, tb = FALSE, ...) {
             stop("replacement of Tu for multisession object requires a list")
         }
         else {
-            temp <- mapply('markocc<-', object, value, SIMPLIFY = FALSE)
+            temp <- mapply('Tu<-', object, value, SIMPLIFY = FALSE)
             class(temp) <- class(object)
             temp
         }
@@ -965,6 +1014,37 @@ flip.default <- function (object, lr = FALSE, tb = FALSE, ...) {
     }
 }
 
+'nontarget<-' <- function (object, value) {
+    
+    if (ms(object)) {
+        if (!is.list(value)) {
+            stop("replacement of nontarget for multisession object requires a list")
+        }
+        else {
+            if (length(value) != length(object)) {
+                stop ("require one non-target matrix for each session")
+            }
+            temp <- mapply('nontarget<-', object, value, SIMPLIFY = FALSE)
+            class(temp) <- class(object)
+            temp
+        }
+    }
+    else {
+        if (!is.null(value)) {
+            if (length(value)>1) {
+                if (length(dims <- dim(value)) != 2)
+                    stop ("require traps x occasions matrix")
+                if (dims[1] != ndetector(traps(object)))
+                    stop ("nontarget not compatible with traps attribute")
+            }
+            if (any(value<0))
+                stop ("nontarget values cannot be negative")
+            value <- as.matrix(value)
+        }
+        structure (object, nontarget = value)
+    }
+}
+
 # 'clusterID<-' <- function (object, value) structure (object, cluster = value)
 # 'clustertrap<-' <- function (object, value) structure (object, clustertrap = value)
 
@@ -1409,6 +1489,7 @@ subset.traps <- function (x, subset = NULL, occasions = NULL, ...) {
             rowsubset <- as.character(polyID(x)) %in% levels(polyID(x))[subset]
         if (all(detector(x) %in% c('transect', 'transectX')))
             rowsubset <- as.character(transectID(x)) %in% levels(transectID(x))[subset]
+        
         ## apply subsetting
         temp <- x[rowsubset,,drop=F]
         class(temp) <- c('traps','data.frame')
@@ -1577,7 +1658,6 @@ subset.capthist <- function (x, subset=NULL, occasions=NULL, traps=NULL,
         return(temp)
     }
     else {
-
         if (is.matrix(x))
             stop("require updated capthist secr >= 3.0")
         trapsx <- secr::traps(x)
@@ -1595,7 +1675,8 @@ subset.capthist <- function (x, subset=NULL, occasions=NULL, traps=NULL,
             stop ("if 'occasions' is logical its length must match number of occasions")
         if (is.logical(traps) & (length(traps) != nk))
             stop ("if 'traps' is logical its length must match number of detectors")
-        if (is.null(occasions)) occasions <- 1:ncol(x)
+        ## 2022-01-04 if (is.null(occasions)) occasions <- 1:ncol(x)
+        if (is.null(occasions)) occasions <- colnum(x)
         if (is.null(traps))  traps <- 1:nk
         if (is.function(subset)) subset <- subset(x, ...)   ## 2017-11-13
         if (is.null(subset)) subset <- 1:nrow(x)
@@ -1611,10 +1692,12 @@ subset.capthist <- function (x, subset=NULL, occasions=NULL, traps=NULL,
             subset <- dimnames(x)[[1]] %in% subset
         else {
             if (is.numeric(subset)) {
-                if (all(subset<0))   # negative implies excludion 2020-09-03
-                    subset <- !(1:nrow(x)) %in% abs(subset)
+                if (all(subset<0))   # negative implies exclusion 2020-09-03
+                  ## 2022-01-04 subset <- !(1:nrow(x)) %in% abs(subset)
+                  subset <- !(rownum %in% abs(subset))
                 else
-                    subset <- (1:nrow(x)) %in% subset
+                  ## 2022-01-04 subset <- (1:nrow(x)) %in% subset
+                  subset <- rownum(x) %in% subset
             }
         }
         
@@ -1628,7 +1711,8 @@ subset.capthist <- function (x, subset=NULL, occasions=NULL, traps=NULL,
             traps <- (1:nk) %in% traps
         }
         if (!is.logical(occasions)) {
-            occasions <- (1:ncol(x)) %in% occasions
+          ## 2022-01-04 occasions <- (1:ncol(x)) %in% occasions
+          occasions <- colnum(x) %in% occasions
         }
         
         if (any(detector=='telemetry')) {
@@ -1768,6 +1852,9 @@ subset.capthist <- function (x, subset=NULL, occasions=NULL, traps=NULL,
         if (!is.null(secr::traps(temp))) {
             usage(secr::traps(temp)) <- usage(trapsx)[traps, occasions,
                   drop = FALSE][,OK2, drop = FALSE]  ## drop null occasions
+            ## 2022-08-09
+            attr(temp, 'nontarget') <- attr(x, 'nontarget')[traps, occasions,
+                drop = FALSE][,OK2, drop = FALSE]  ## drop null occasions
         }
 
         if (length(detector(trapsx))>1)
@@ -2145,176 +2232,6 @@ read.mask <- function (file = NULL, data = NULL, spacing = NULL, columns = NULL,
 }
 ###############################################################################
 
-summary.mask <- function(object, ...) {
-
-  if (ms(object)) {
-      temp <- lapply(object, summary.mask)
-      class(temp) <- c('summary.mask', 'list')
-      temp
-  }
-  else {
-      if (is.null(object$x) | is.null(object$y))
-          stop ("not a valid mask")
-      nd <- length(object$x)
-      if (length(object$x) != length(object$y))
-          stop  ("not a valid mask")
-
-      if (!is.null(covariates(object))) {
-          sumcovar <- summary(covariates(object), ...)
-      } else sumcovar <- NULL
-      if (inherits(object, 'linearmask'))
-          maskclass <- 'linearmask'
-      else if (inherits(object,'Dsurface'))
-          maskclass <- 'Dsurface'
-      else if (inherits(object,'Rsurface'))
-          maskclass <- 'Rsurface'
-      else
-          maskclass <- 'mask'
-
-      ## rearranged 2014-09-06
-      temp <- list (
-        maskclass = maskclass,
-        masktype = attr(object, 'type',exact = TRUE),
-        nmaskpoints = nrow(object),
-        xrange = range(object$x),
-        yrange = range(object$y),
-        meanSD = attr(object, 'meanSD',exact = TRUE),
-        spacing = attr(object, 'spacing',exact = TRUE),
-        cellarea = attr(object, 'area',exact = TRUE),
-        boundingbox = attr(object, 'boundingbox',exact = TRUE),
-        covar = sumcovar
-      )
-      class(temp) <- 'summary.mask'
-      temp
-  }
-
-}
-############################################################################################
-
-print.summary.mask <- function (x, ...) {
-    if (ms(x)) {
-        lapply (x, print.summary.mask)
-    }
-    else {
-      cat ('Object class     ', x$maskclass, '\n')
-      cat ('Mask type        ', x$masktype, '\n')
-      cat ('Number of points ', x$nmaskpoints, '\n')
-      cat ('Spacing m        ', x$spacing, '\n')
-      if (is.null(x$cellarea))
-          cat ('Total length km  ', x$spacing * x$nmaskpoints / 1000, '\n')
-      else {
-          cat ('Cell area ha     ', x$cellarea, '\n')
-          cat ('Total area ha    ', x$cellarea * x$nmaskpoints, '\n')
-      }
-      cat ('x-range m        ', x$xrange, '\n')
-      cat ('y-range m        ', x$yrange, '\n')
-      cat ('Bounding box     ','\n')
-      print (x$boundingbox, ...)
-      cat ('\n')
-      if (!is.null(x$covar)) {
-          cat ('Summary of covariates', '\n')
-          print(x$covar, ...)
-      }
-  }
-}
-############################################################################################
-
-summary.popn <- function(object, collapse = FALSE, ...) {
-  ## 2019-06-10
-  if (ms(object)) {
-      if (collapse) {
-          pop1 <- do.call(rbind, object)
-          temp <- summary(pop1)
-          temp$collapsed <- TRUE
-          # if (!is.null(covariates(pop1))) {
-          #     temp$covar <- summary(covariates(pop1), ...)
-          # } else 
-          temp$covar <- NULL
-          pop2 <- popIDsplit(object)   # dim = c(length(ID), nsess, 2); see plot.popn.R
-          move <- function (sessxy) sqrt(diff(sessxy[,1])^2 + diff(sessxy[,2])^2)
-          m <- t(apply(pop2,1,move))
-          temp$nanimals <- nrow(pop2)
-          temp$nsessions <- ncol(pop2)
-          pop2 <- pop2[,,1]
-          pop2[!is.na(pop2)] <- 1 
-          pop2[is.na(pop2)] <- 0
-          pop2 <- t(apply(pop2, 1, function(x) {x[x==0 & cumsum(x)>0] <- -1; x}))
-          # 0 not yet recruited; 1 alive; -1 dead
-          recruited <- function(x) c(x[1], diff(x) == 1)    # 0 -> 1
-          died <- function(x) c(0, diff(x) == -2)           # 1 -> -1
-          temp$recruits <- apply(apply(pop2,1,recruited),1,sum)
-          temp$deaths <- apply(apply(pop2,1,died),1,sum)
-          temp$movements <- m
-          temp$status <- pop2
-          temp
-      }
-      else {
-          temp <- lapply(object, summary.popn)
-          class(temp) <- c('summary.popn', 'list')
-      }
-      temp
-  }
-  else {
-      if (is.null(object$x) | is.null(object$y))
-          stop ("not a valid popn")
-      nd <- length(object$x)
-      if (length(object$x) != length(object$y))
-          stop  ("not a valid popn")
-
-      if (!is.null(covariates(object))) {
-          sumcovar <- summary(covariates(object), ...)
-      } else sumcovar <- NULL
-      
-      popnclass <- 'popn'
-
-      ## rearranged 2014-09-06
-      temp <- list (
-        popnclass = popnclass,
-        nanimals = nrow(object),
-        xrange = range(object$x),
-        yrange = range(object$y),
-        boundingbox = attr(object, 'boundingbox',exact = TRUE),
-        covar = sumcovar,
-        collapsed = FALSE
-      )
-      class(temp) <- 'summary.popn'
-      temp
-  }
-
-}
-############################################################################################
-
-print.summary.popn <- function (x, ...) {
-    if (ms(x)) {
-        lapply (x, print.summary.popn)
-    }
-    else {
-      cat ('Object class        ', x$popnclass, '\n')
-      cat ('Number of animals   ', x$nanimals, '\n')
-      if (x$collapsed) {
-          cat ('Sessions            ', x$nsessions, '\n')
-          cat ('Animals  by session ', paste(apply(x$status==1,2,sum,na.rm=TRUE), collapse=', '), '\n')
-          cat ('Recruits by session ', paste(x$recruits, collapse = ', '), '\n')
-          cat ('Deaths   by session ', paste(x$deaths, collapse = ', '), '\n')
-          cat ('Average move        ', round(mean(as.numeric(x$movements), na.rm = TRUE),2), '\n')
-          cat ('\n')
-      }      
-      cat ('x-range m        ', x$xrange, '\n')
-      cat ('y-range m        ', x$yrange, '\n')
-      cat ('Bounding box     ','\n')
-      print (x$boundingbox, ...)
-      if (!is.null(x$covar)) {
-          cat ('Summary of covariates', '\n')
-          print(x$covar, ...)
-      }
-      cat('\n')
-  }
-}
-############################################################################################
-
-
-
-
 ####################################################
 ## Class : secr
 ## spatially explicit capture-recapture model fit
@@ -2328,7 +2245,7 @@ trim.secr <- function (object, drop = c('call', 'mask', 'designD', 'designNE',
 }
 ############################################################################################
 
-## 2012-11-14, 2017-10-27, 2017-12-13
+## 2012-11-14, 2017-10-27, 2017-12-13, 2022-04-17
 secrlist <- function(...) {
     dots <- match.call(expand.dots = FALSE)$...
     allargs <- list(...)
@@ -2341,12 +2258,12 @@ secrlist <- function(...) {
             names(allargs) <- sapply(dots2, deparse)
         }
 
-        allargs <- lapply(allargs, function(x) if (inherits(x, 'secr')) list(x) else x)
+        allargs <- lapply(allargs, function(x) if (inherits(x, c('secr','ipsecr'))) list(x) else x)
         temp <- do.call(c, allargs)
         ## added 2013-06-06
         if (is.null(names(temp)))
             names(temp) <- paste("secr", 1:length(temp), sep="")
-        if (!all(sapply(temp, function(x) inherits(x, 'secr'))))
+        if (!all(sapply(temp, function(x) inherits(x, c('secr','ipsecr')))))
             stop ("objects must be of class 'secr' or 'secrlist'")
         class(temp) <- 'secrlist'
         temp
@@ -2671,9 +2588,11 @@ vcov.secr <- function (object, realnames = NULL, newdata = NULL, byrow = FALSE,
                 reali <- function (beta, rn) {
                     ## real from all beta pars eval at newdata[i,]
                     par.rn <- object$parindx[[rn]]
-                    mat <- general.model.matrix(object$model[[rn]], data = newdatai,
-                                                gamsmth = object$smoothsetup[[rn]],
-                                                contrasts = object$details$contrasts)
+                    mat <- general.model.matrix(
+                        object$model[[rn]], 
+                        data = newdatai,
+                        gamsmth = object$smoothsetup[[rn]],
+                        contrasts = object$details$contrasts)
                     lp <- mat %*% matrix(beta[par.rn], ncol = 1)
                     untransform (lp, object$link[[rn]])
                 }
@@ -2700,9 +2619,11 @@ vcov.secr <- function (object, realnames = NULL, newdata = NULL, byrow = FALSE,
                 if (rn == 'pmix')
                     stop("vcov does not work at present when realname == 'pmix'")
                 par.rn <- object$parindx[[rn]]
-                mat <- general.model.matrix(object$model[[rn]], data = newdata,
-                                            gamsmth = object$smoothsetup[[rn]],
-                                            contrasts = object$details$contrasts)
+                mat <- general.model.matrix(
+                    object$model[[rn]], 
+                    data = newdata,
+                    gamsmth = object$smoothsetup[[rn]],
+                    contrasts = object$details$contrasts)
                 lp <- mat %*% matrix(object$fit$par[par.rn], ncol = 1)
                 real <- untransform (lp, object$link[[rn]])
                 real <- as.vector(real)
